# Demo program for tkgeomap
# Creates a tkgeomap widget embedded in a canvas widget
# Uses outline data from GROUP3, contiental and international
#   political boundaries, detailed U.S. state boundaries from 
#   ftp://ncardata.ucar.edu/datasets/ds780.0/data.
# Uses geoplaces from http://www.nws.noaa.gov/pub/stninfo/nsd_cccc.txt.

# Local root (adjust for your file system)
set top $env(HOME)

# Directories
set binDir $top/bin
set libDir $top/lib
set lineDir $top/tkmaps/data/lines
set placeDir $top/tkmaps/data/places

# Identify tkgeomap package
if {[lsearch [info commands] tkgeomap] == -1} {
  load $libDir/libtkGeoMap.so tkgeomap
}
source $libDir/tkGeoMapProcs.tcl

# Load NCAR Continental Outline Set, GROUP3 (Continental, international,
#  and U.S. state boundaries)
puts "Loading lat's and lon's"
geolinearray fmxdr group3 $lineDir/GROUP3

puts "Making grid lines"

# Make grid lines on latitude circles
for {set lon -180} {$lon <= 180} {incr lon 2} {lappend lons $lon}
set gridLats {-90 -75 -60 -45 -30 -15 0 15 30 45 60 75 90}
foreach lat $gridLats {
  foreach lon $lons {
    lappend latCircle "$lat $lon"
  }
  lappend grid $latCircle
  unset latCircle
}

# Make grid lines on meridians
for {set lon -180} {$lon <= 180} {incr lon 15} {lappend gridLons $lon}
for {set lat -90} {$lat <= 90} {incr lat 2} {lappend lats $lat}
foreach lon $gridLons {
  foreach lat $lats {
    lappend meridian "$lat $lon"
  }
  lappend grid $meridian
  unset meridian
}

geolinearray fmlist grid $grid

# Load weather stations
puts "Loading weather stations"
source $placeDir/stations.tcl

# Create a tkgeomap and menu in a canvas in a frame 
set params(center) {30.0 -96.0}
set params(projection) Orthographic
set params(scale) 1:90000000
set params(cvsWidth) 600
set params(cvsHeight) 600
frame .f
MapCanvas .f params    ;# Returns canvas .f.c with map .f.c.g
.f.c config -bg Wheat
.f.c.g config -bg Wheat -linecolor Blue4 -dotcolor Green4 \
  -dotsize 1 -textcolor Black

# Draw lines and places
.f.c.g lines group3
.f.c.g lines grid -c #808080 -y LineOnOffDash
foreach place [geoplace list] {
  .f.c.g drawdot $place
}

# Make double-2 reveal station info
set count 0
set descr(0) "0"
set index(0) "0"

bind .f.c.g <Double-2> {
# Get name of place closest to the double click
  set place [geoplace nearest [.f.c.g XToLatLon "%x %y"]]

# Add it to the array of places and put its number on the map
  if {[lsearch [array names index] $place] == -1} {
    incr count
    set index($place) $count
    .f.c.g Text $place $index($place)
  }

# Send information about the place to the terminal
# You could also use place as input to other commands, e.g. get metar
#   reports, warnings, etc.
  puts "$index($place) $descr($place)"
}
puts "Double-2 to see station info"

pack .f -expand true -fill both

